/*
 * This file is part of unity-2d
 *
 * Copyright 2010-2011 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1
import Unity2d 1.0

Item {
    id: shell
    Accessible.name: "shell"

    /* We can't use availableGeometry.width because it was implemented so that it always subtracts
       from the available space the width of the launcher.
       TODO: fix it in libunity-2d-private when we everything is merged into one single shell */
    width: screen.geometry.width
    height: screen.availableGeometry.height

    property string playerSource: ""
    property bool playerActive: false
    onPlayerActiveChanged: if (playerActive) player.focus = true

    Loader {
        id: player
        source: "player/VideoPlayer.qml"
        anchors.fill: parent
        onLoaded: player.item.focus = true
    }

    Loader {
        id: launcher
        source: "launcher/Launcher.qml"
        anchors.top: parent.top
        KeyNavigation.right: dash
        onStatusChanged: {
            /* This is needed because if the dash finish loading before the launcher we won't get
               the dashActiveChanged signal, and we're going to autohide instead of being forced
               visibile. */
            if (status == Loader.Ready && dash.status == Loader.Ready && declarativeView.dashActive)
                launcher.item.visibilityController.beginForceVisible("dash")
       }
       onActiveFocusChanged: {
           if (activeFocus) item.visibilityController.beginForceVisible("launcher")
           else item.visibilityController.endForceVisible("launcher")
       }
    }

    Loader {
        id: dash
        source: "dash/Dash.qml"
        anchors.top: parent.top
        anchors.left: launcher.right
        KeyNavigation.left: launcher
        onLoaded: dash.item.focus = true
    }

    Connections {
        target: declarativeView
        onDashActiveChanged: if (declarativeView.dashActive) dash.focus = true
        onLauncherFocusRequested: launcher.focus = true
        onFocusChanged: {
            /* FIXME: The launcher is forceVisible while it has activeFocus. However even though
               the documentation says that setting focus=false will make an item lose activeFocus
               if it has it, this doesn't happen with FocusScopes (and Loader is a FocusScope).
               Therefore I'm working around this by giving focus to the shell, which is safe since
               the shell doesn't react to activeFocus at all.
               See: https://bugreports.qt.nokia.com/browse/QTBUG-19688 */
            if (!declarativeView.focus && launcher.activeFocus) shell.focus = true
        }
    }

    Component.onCompleted: declarativeView.show()
}
