import QtQuick 1.0
import QtMultimediaKit 1.1

Player {
    id: player
    opacity: shell.playerActive ? 1.0 : 0.0

    property int pressCount: 0

    function playUri(uri) {
        source = uri
        play()
    }

    function play() {
        state = "playing"
        declarativeView.dashActive = false
        shell.playerActive = true
    }

    function stop() {
        state = "stopped"
        declarativeView.dashActive = true
        shell.playerActive = false
        shell.playerSource = ""
    }

    Connections {
        target: shell
        onPlayerSourceChanged: {
            if (shell.playerSource) { player.playUri(shell.playerSource) }
            else { player.stop() }
        }
        onPlayerActiveChanged: {
            if (shell.playerActive && shell.playerSource) { player.play() }
            else { player.stop() }
        }
    }

    onStatusChanged: {
        if (status == Video.EndOfMedia) {
            stop()
        }
    }

    Keys.onPressed: {
        if (!event.isAutoRepeat && (event.key == Qt.Key_Space || event.key == Qt.Key_P || event.key == Qt.Key_MediaPause || event.key == Qt.Key_MediaPlay)) {
            if (!playing) { play() }
            else { pause() }
        } else if (event.key == Qt.Key_Left || event.key == Qt.Key_Right) {
            if (event.isAutoRepeat) { pressCount += 1 }
            else { pressCount = 1 }
        } else if (!event.isAutoRepeat && event.key == Qt.Key_X || event.key == Qt.Key_MediaStop || event.key == Qt.Key_Escape) {
            stop()
        }
    }

    Keys.onReleased: {
        if (event.key == Qt.Key_Left || event.key == Qt.Key_Right) {
            if (!event.isAutoRepeat && pressCount == 1) {
                if (event.key == Qt.Key_Left) { seekBackward() }
                else { seekForward() }
            } else if ((event.isAutoRepeat && pressCount == 1) || ((pressCount % 20) == 0)) {
                if (event.key == Qt.Key_Left) { rewind() }
                else { fastForward() }
            }
        }
    }
}
