/*
 * This file is part of unity-2d
 *
 * Copyright 2011 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

.pragma library

/* Default color pallette */
var orange = "#DD4814"
var canonicalAubergine = "#772953"
var lightAubergine = "#77216F"
var mediumAubergine = "#5E2750"
var darkAubergine = "#2C001E"
var warmGrey = "#AEA79F"
var coolGrey = "#333333"

/* Convert strings like "one-two-three" to "OneTwoThree" */
function convertToCamelCase( name ) {
    var chunksArray = name.split('-')
    var camelName = ''
    for (var i=0; i<chunksArray.length; i++){
        camelName = camelName + chunksArray[i].charAt(0).toUpperCase() + chunksArray[i].slice(1);
    }
    return camelName
}

function clamp(x, min, max) {
    return Math.max(Math.min(x, max), min)
}

function hashEmpty(hash) {
    for (var key in hash) return false;
    return true
}

function get_human_time_format(time_in_milliseconds)
{
    var date = new Date(time_in_milliseconds)

    if(date.getUTCHours() == 0) return "mm:ss"
    else return "hh:mm:ss"
}

function format_time(time_in_milliseconds, formatting) {
    /* We are using Qt.formatTime to format the time_in_milliseconds because
       this is more practical that doing the formatting manually (JavaScript
       does not provide any string formatting function natively).

       WARNING: this will break for media longer than 24 hours.
    */

    /* Hack JavaScript's Date to ignore timeone offset */
    var zero = new Date(0)
    var offset = zero.getTimezoneOffset()*60*1000
    var date = new Date(time_in_milliseconds+offset)

    return Qt.formatTime(date, formatting)
}
